==> lightdash_client_python-0.1249.0.tar.gz: lightdash_client_python-0.1249.0/lightdash_client/api/git_integration/create_pull_request_for_custom_metrics.py <==
from http import HTTPStatus
from typing import Any, Dict, Optional, Union

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.create_pull_request_for_custom_metrics_body import (
    CreatePullRequestForCustomMetricsBody,
)
from ...models.create_pull_request_for_custom_metrics_response_200 import (
    CreatePullRequestForCustomMetricsResponse200,
)
from ...types import Response


def _get_kwargs(
    project_uuid: str,
    *,
    body: CreatePullRequestForCustomMetricsBody,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "post",
        "url": f"/api/v1/projects/{project_uuid}/git-integration/pull-requests/custom-metrics",
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[CreatePullRequestForCustomMetricsResponse200]:
    if response.status_code == HTTPStatus.OK:
        response_200 = CreatePullRequestForCustomMetricsResponse200.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[CreatePullRequestForCustomMetricsResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreatePullRequestForCustomMetricsBody,
) -> Response[CreatePullRequestForCustomMetricsResponse200]:
    """
    Args:
        project_uuid (str):
        body (CreatePullRequestForCustomMetricsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[CreatePullRequestForCustomMetricsResponse200]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreatePullRequestForCustomMetricsBody,
) -> Optional[CreatePullRequestForCustomMetricsResponse200]:
    """
    Args:
        project_uuid (str):
        body (CreatePullRequestForCustomMetricsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        CreatePullRequestForCustomMetricsResponse200
    """

    return sync_detailed(
        project_uuid=project_uuid,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreatePullRequestForCustomMetricsBody,
) -> Response[CreatePullRequestForCustomMetricsResponse200]:
    """
    Args:
        project_uuid (str):
        body (CreatePullRequestForCustomMetricsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[CreatePullRequestForCustomMetricsResponse200]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreatePullRequestForCustomMetricsBody,
) -> Optional[CreatePullRequestForCustomMetricsResponse200]:
    """
    Args:
        project_uuid (str):
        body (CreatePullRequestForCustomMetricsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        CreatePullRequestForCustomMetricsResponse200
    """

    return (
        await asyncio_detailed(
            project_uuid=project_uuid,
            client=client,
            body=body,
        )
    ).parsed

==> lightdash_client_python-0.1398.0.tar.gz: lightdash_client_python-0.1398.0/lightdash_client/api/git_integration/create_pull_request_for_custom_metrics.py <==
from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union, cast

import httpx

from ... import errors
from ...client import AuthenticatedClient, Client
from ...models.create_pull_request_for_custom_metrics_body import CreatePullRequestForCustomMetricsBody
from ...models.create_pull_request_for_custom_metrics_response_200 import CreatePullRequestForCustomMetricsResponse200
from ...types import UNSET, Response


def _get_kwargs(
    project_uuid: str,
    *,
    body: CreatePullRequestForCustomMetricsBody,
) -> Dict[str, Any]:
    headers: Dict[str, Any] = {}

    _kwargs: Dict[str, Any] = {
        "method": "post",
        "url": "/api/v1/projects/{projectUuid}/git-integration/pull-requests/custom-metrics".format(
            projectUuid=project_uuid,
        ),
    }

    _body = body.to_dict()

    _kwargs["json"] = _body
    headers["Content-Type"] = "application/json"

    _kwargs["headers"] = headers
    return _kwargs


def _parse_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Optional[CreatePullRequestForCustomMetricsResponse200]:
    if response.status_code == HTTPStatus.OK:
        response_200 = CreatePullRequestForCustomMetricsResponse200.from_dict(response.json())

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(response.status_code, response.content)
    else:
        return None


def _build_response(
    *, client: Union[AuthenticatedClient, Client], response: httpx.Response
) -> Response[CreatePullRequestForCustomMetricsResponse200]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreatePullRequestForCustomMetricsBody,
) -> Response[CreatePullRequestForCustomMetricsResponse200]:
    """
    Args:
        project_uuid (str):
        body (CreatePullRequestForCustomMetricsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[CreatePullRequestForCustomMetricsResponse200]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        body=body,
    )

    response = client.get_httpx_client().request(
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreatePullRequestForCustomMetricsBody,
) -> Optional[CreatePullRequestForCustomMetricsResponse200]:
    """
    Args:
        project_uuid (str):
        body (CreatePullRequestForCustomMetricsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        CreatePullRequestForCustomMetricsResponse200
    """

    return sync_detailed(
        project_uuid=project_uuid,
        client=client,
        body=body,
    ).parsed


async def asyncio_detailed(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreatePullRequestForCustomMetricsBody,
) -> Response[CreatePullRequestForCustomMetricsResponse200]:
    """
    Args:
        project_uuid (str):
        body (CreatePullRequestForCustomMetricsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[CreatePullRequestForCustomMetricsResponse200]
    """

    kwargs = _get_kwargs(
        project_uuid=project_uuid,
        body=body,
    )

    response = await client.get_async_httpx_client().request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_uuid: str,
    *,
    client: Union[AuthenticatedClient, Client],
    body: CreatePullRequestForCustomMetricsBody,
) -> Optional[CreatePullRequestForCustomMetricsResponse200]:
    """
    Args:
        project_uuid (str):
        body (CreatePullRequestForCustomMetricsBody):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        CreatePullRequestForCustomMetricsResponse200
    """

    return (
        await asyncio_detailed(
            project_uuid=project_uuid,
            client=client,
            body=body,
        )
    ).parsed
